[Scipy-svn] r3515 - in trunk/scipy: lib/blas/tests lib/lapack/tests linalg/tests misc/tests optimize/tests sparse/tests weave/tests

scipy-svn at scipy.org scipy-svn at scipy.org
Mon Nov 12 23:18:32 EST 2007


Author: jarrod.millman
Date: 2007-11-12 22:18:23 -0600 (Mon, 12 Nov 2007)
New Revision: 3515

Modified:
   trunk/scipy/lib/blas/tests/test_fblas.py
   trunk/scipy/lib/lapack/tests/test_lapack.py
   trunk/scipy/linalg/tests/test_basic.py
   trunk/scipy/linalg/tests/test_fblas.py
   trunk/scipy/misc/tests/test_pilutil.py
   trunk/scipy/optimize/tests/test_zeros.py
   trunk/scipy/sparse/tests/test_sparse.py
   trunk/scipy/weave/tests/test_build_tools.py
   trunk/scipy/weave/tests/test_c_spec.py
   trunk/scipy/weave/tests/test_numpy_scalar_spec.py
   trunk/scipy/weave/tests/test_scxx_sequence.py
   trunk/scipy/weave/tests/test_size_check.py
Log:
switching test_cases to CapWords


Modified: trunk/scipy/lib/blas/tests/test_fblas.py
===================================================================
--- trunk/scipy/lib/blas/tests/test_fblas.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/lib/blas/tests/test_fblas.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -40,7 +40,7 @@
 ##################################################
 ### Test blas ?axpy
 
-class base_axpy(NumpyTestCase):
+class BaseAxpy(NumpyTestCase):
     def check_default_a(self):
         x = arange(3.,dtype=self.dtype)
         y = arange(3.,dtype=x.dtype)
@@ -92,21 +92,21 @@
         assert(0)
 
 try:
-    class test_saxpy(base_axpy):
+    class TestSaxpy(BaseAxpy):
         blas_func = fblas.saxpy
         dtype = float32
 except AttributeError:
-    class test_saxpy: pass
-class test_daxpy(base_axpy):
+    class TestSaxpy: pass
+class TestDaxpy(BaseAxpy):
     blas_func = fblas.daxpy
     dtype = float64
 try:
-    class test_caxpy(base_axpy):
+    class TestCaxpy(BaseAxpy):
         blas_func = fblas.caxpy
         dtype = complex64
 except AttributeError:
-    class test_caxpy: pass
-class test_zaxpy(base_axpy):
+    class TestCaxpy: pass
+class TestZaxpy(BaseAxpy):
     blas_func = fblas.zaxpy
     dtype = complex128
 
@@ -114,7 +114,7 @@
 ##################################################
 ### Test blas ?scal
 
-class base_scal(NumpyTestCase):
+class BaseScal(NumpyTestCase):
     def check_simple(self):
         x = arange(3.,dtype=self.dtype)
         real_x = x*3.
@@ -135,21 +135,21 @@
         # should catch error and never get here
         assert(0)
 try:
-    class test_sscal(base_scal):
+    class TestSscal(BaseScal):
         blas_func = fblas.sscal
         dtype = float32
 except AttributeError:
-    class test_sscal: pass
-class test_dscal(base_scal):
+    class TestSscal: pass
+class TestDscal(BaseScal):
     blas_func = fblas.dscal
     dtype = float64
 try:
-    class test_cscal(base_scal):
+    class TestCscal(BaseScal):
         blas_func = fblas.cscal
         dtype = complex64
 except AttributeError:
-    class test_cscal: pass
-class test_zscal(base_scal):
+    class TestCscal: pass
+class TestZscal(BaseScal):
     blas_func = fblas.zscal
     dtype = complex128
 
@@ -159,7 +159,7 @@
 ##################################################
 ### Test blas ?copy
 
-class base_copy(NumpyTestCase):
+class BaseCopy(NumpyTestCase):
     def check_simple(self):
         x = arange(3.,dtype=self.dtype)
         y = zeros(shape(x),x.dtype)
@@ -206,21 +206,21 @@
     #    assert_array_almost_equal(x,y)
 
 try:
-    class test_scopy(base_copy):
+    class TestScopy(BaseCopy):
         blas_func = fblas.scopy
         dtype = float32
 except AttributeError:
-    class test_scopy: pass
-class test_dcopy(base_copy):
+    class TestScopy: pass
+class TestDcopy(BaseCopy):
     blas_func = fblas.dcopy
     dtype = float64
 try:
-    class test_ccopy(base_copy):
+    class TestCcopy(BaseCopy):
         blas_func = fblas.ccopy
         dtype = complex64
 except AttributeError:
-    class test_ccopy: pass
-class test_zcopy(base_copy):
+    class TestCcopy: pass
+class TestZcopy(BaseCopy):
     blas_func = fblas.zcopy
     dtype = complex128
 
@@ -228,7 +228,7 @@
 ##################################################
 ### Test blas ?swap
 
-class base_swap(NumpyTestCase):
+class BaseSwap(NumpyTestCase):
     def check_simple(self):
         x = arange(3.,dtype=self.dtype)
         y = zeros(shape(x),x.dtype)
@@ -282,21 +282,21 @@
         assert(0)
 
 try:
-    class test_sswap(base_swap):
+    class TestSswap(BaseSwap):
         blas_func = fblas.sswap
         dtype = float32
 except AttributeError:
-    class test_sswap: pass
-class test_dswap(base_swap):
+    class TestSswap: pass
+class TestDswap(BaseSwap):
     blas_func = fblas.dswap
     dtype = float64
 try:
-    class test_cswap(base_swap):
+    class TestCswap(BaseSwap):
         blas_func = fblas.cswap
         dtype = complex64
 except AttributeError:
-    class test_cswap: pass
-class test_zswap(base_swap):
+    class TestCswap: pass
+class TestZswap(BaseSwap):
     blas_func = fblas.zswap
     dtype = complex128
 
@@ -304,7 +304,7 @@
 ### Test blas ?gemv
 ### This will be a mess to test all cases.
 
-class base_gemv(NumpyTestCase):
+class BaseGemv(NumpyTestCase):
     def get_data(self,x_stride=1,y_stride=1):
         mult = array(1, dtype = self.dtype)
         if self.dtype in [complex64, complex128]:
@@ -386,21 +386,21 @@
             pass
 
 try:
-    class test_sgemv(base_gemv):
+    class TestSgemv(BaseGemv):
         blas_func = fblas.sgemv
         dtype = float32
 except AttributeError:
-    class test_sgemv: pass
-class test_dgemv(base_gemv):
+    class TestSgemv: pass
+class TestDgemv(BaseGemv):
     blas_func = fblas.dgemv
     dtype = float64
 try:
-    class test_cgemv(base_gemv):
+    class TestCgemv(BaseGemv):
         blas_func = fblas.cgemv
         dtype = complex64
 except AttributeError:
-    class test_cgemv: pass
-class test_zgemv(base_gemv):
+    class TestCgemv: pass
+class TestZgemv(BaseGemv):
     blas_func = fblas.zgemv
     dtype = complex128
 
@@ -409,7 +409,7 @@
 ### Test blas ?ger
 ### This will be a mess to test all cases.
 
-class base_ger(NumpyTestCase):
+class BaseGer(NumpyTestCase):
     def get_data(self,x_stride=1,y_stride=1):
         from numpy.random import normal
         alpha = array(1., dtype = self.dtype)
@@ -449,10 +449,10 @@
         except:
             pass
 
-class test_sger(base_ger):
+class TestSger(BaseGer):
     blas_func = fblas.sger
     dtype = float32
-class test_dger(base_ger):
+class TestDger(BaseGer):
     blas_func = fblas.dger
     dtype = float64
 """
@@ -461,7 +461,7 @@
 ### This will be a mess to test all cases.
 
 """
-class base_ger_complex(base_ger):
+class BaseGerComplex(BaseGer):
     def get_data(self,x_stride=1,y_stride=1):
         from numpy.random import normal
         alpha = array(1+1j, dtype = self.dtype)
@@ -493,24 +493,24 @@
     #    self.blas_func(x,y,a,incy=2)
     #    assert_array_almost_equal(desired_a,a)
 
-class test_cgeru(base_ger_complex):
+class TestCgeru(BaseGerComplex):
     blas_func = fblas.cgeru
     dtype = complex64
     def transform(self,x):
         return x
-class test_zgeru(base_ger_complex):
+class TestZgeru(BaseGerComplex):
     blas_func = fblas.zgeru
     dtype = complex128
     def transform(self,x):
         return x
 
-class test_cgerc(base_ger_complex):
+class TestCgerc(BaseGerComplex):
     blas_func = fblas.cgerc
     dtype = complex64
     def transform(self,x):
         return conjugate(x)
 
-class test_zgerc(base_ger_complex):
+class TestZgerc(BaseGerComplex):
     blas_func = fblas.zgerc
     dtype = complex128
     def transform(self,x):

Modified: trunk/scipy/lib/lapack/tests/test_lapack.py
===================================================================
--- trunk/scipy/lib/lapack/tests/test_lapack.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/lib/lapack/tests/test_lapack.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -27,7 +27,7 @@
 
 #class _test_ev: pass
 
-class _test_lapack(NumpyTestCase,
+class _TestLapack(NumpyTestCase,
                    _test_ev,
                    _test_gev):
 
@@ -84,16 +84,16 @@
 ****************************************************************
 """
 else:
-    class test_flapack_double(_test_lapack):
+    class TestFlapackDouble(_TestLapack):
         lapack = PrefixWrapper(flapack,'d')
         decimal = 12
-    class test_flapack_float(_test_lapack):
+    class TestFlapackFloat(_TestLapack):
         lapack = PrefixWrapper(flapack,'s')
         decimal = 5
-    class test_flapack_complex(_test_lapack):
+    class TestFlapackComplex(_TestLapack):
         lapack = PrefixWrapper(flapack,'c')
         decimal = 5
-    class test_flapack_double_complex(_test_lapack):
+    class TestFlapackDoubleComplex(_TestLapack):
         lapack = PrefixWrapper(flapack,'z')
         decimal = 12
 
@@ -109,16 +109,16 @@
 ****************************************************************
 """
 else:
-    class test_clapack_double(_test_lapack):
+    class TestClapackDouble(_TestLapack):
         lapack = PrefixWrapper(clapack,'d')
         decimal = 12
-    class test_clapack_float(_test_lapack):
+    class TestClapackFloat(_TestLapack):
         lapack = PrefixWrapper(clapack,'s')
         decimal = 5
-    class test_clapack_complex(_test_lapack):
+    class TestClapackComplex(_TestLapack):
         lapack = PrefixWrapper(clapack,'c')
         decimal = 5
-    class test_clapack_double_complex(_test_lapack):
+    class TestClapackDoubleComplex(_TestLapack):
         lapack = PrefixWrapper(clapack,'z')
         decimal = 12
 

Modified: trunk/scipy/linalg/tests/test_basic.py
===================================================================
--- trunk/scipy/linalg/tests/test_basic.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/linalg/tests/test_basic.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -414,7 +414,7 @@
             #XXX: check definition of res
             assert_array_almost_equal(x,direct_lstsq(a,b,1))
 
-class test_tri(NumpyTestCase):
+class TestTri(NumpyTestCase):
     def check_basic(self):
         assert_equal(tri(4),array([[1,0,0,0],
                                    [1,1,0,0],
@@ -450,7 +450,7 @@
                                           [1,0,0],
                                           [1,1,0]]))
 
-class test_tril(NumpyTestCase):
+class TestTril(NumpyTestCase):
     def check_basic(self):
         a = (100*get_mat(5)).astype('l')
         b = a.copy()
@@ -472,7 +472,7 @@
                 b[k,l] = 0
         assert_equal(tril(a,k=-2),b)
 
-class test_triu(NumpyTestCase):
+class TestTriu(NumpyTestCase):
     def check_basic(self):
         a = (100*get_mat(5)).astype('l')
         b = a.copy()
@@ -494,14 +494,14 @@
                 b[l,k] = 0
         assert_equal(triu(a,k=-2),b)
 
-class test_toeplitz(NumpyTestCase):
+class TestToeplitz(NumpyTestCase):
     def check_basic(self):
         y = toeplitz([1,2,3])
         assert_array_equal(y,[[1,2,3],[2,1,2],[3,2,1]])
         y = toeplitz([1,2,3],[1,4,5])
         assert_array_equal(y,[[1,4,5],[2,1,4],[3,2,1]])
 
-class test_hankel(NumpyTestCase):
+class TestHankel(NumpyTestCase):
     def check_basic(self):
         y = hankel([1,2,3])
         assert_array_equal(y,[[1,2,3],[2,3,0],[3,0,0]])

Modified: trunk/scipy/linalg/tests/test_fblas.py
===================================================================
--- trunk/scipy/linalg/tests/test_fblas.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/linalg/tests/test_fblas.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -40,7 +40,7 @@
 ##################################################
 ### Test blas ?axpy
 
-class base_axpy(NumpyTestCase):
+class BaseAxpy(NumpyTestCase):
     def check_default_a(self):
         x = arange(3.,dtype=self.dtype)
         y = arange(3.,dtype=x.dtype)
@@ -92,21 +92,21 @@
         assert(0)
 
 try:
-    class test_saxpy(base_axpy):
+    class TestSaxpy(BaseAxpy):
         blas_func = fblas.saxpy
         dtype = float32
 except AttributeError:
-    class test_saxpy: pass
-class test_daxpy(base_axpy):
+    class TestSaxpy: pass
+class TestDaxpy(BaseAxpy):
     blas_func = fblas.daxpy
     dtype = float64
 try:
-    class test_caxpy(base_axpy):
+    class TestCaxpy(BaseAxpy):
         blas_func = fblas.caxpy
         dtype = complex64
 except AttributeError:
-    class test_caxpy: pass
-class test_zaxpy(base_axpy):
+    class TestCaxpy: pass
+class TestZaxpy(BaseAxpy):
     blas_func = fblas.zaxpy
     dtype = complex128
 
@@ -114,7 +114,7 @@
 ##################################################
 ### Test blas ?scal
 
-class base_scal(NumpyTestCase):
+class BaseScal(NumpyTestCase):
     def check_simple(self):
         x = arange(3.,dtype=self.dtype)
         real_x = x*3.
@@ -135,21 +135,21 @@
         # should catch error and never get here
         assert(0)
 try:
-    class test_sscal(base_scal):
+    class TestSscal(BaseScal):
         blas_func = fblas.sscal
         dtype = float32
 except AttributeError:
-    class test_sscal: pass
-class test_dscal(base_scal):
+    class TestSscal: pass
+class TestDscal(BaseScal):
     blas_func = fblas.dscal
     dtype = float64
 try:
-    class test_cscal(base_scal):
+    class TestCscal(BaseScal):
         blas_func = fblas.cscal
         dtype = complex64
 except AttributeError:
-    class test_cscal: pass
-class test_zscal(base_scal):
+    class TestCscal: pass
+class TestZscal(BaseScal):
     blas_func = fblas.zscal
     dtype = complex128
 
@@ -159,7 +159,7 @@
 ##################################################
 ### Test blas ?copy
 
-class base_copy(NumpyTestCase):
+class BaseCopy(NumpyTestCase):
     def check_simple(self):
         x = arange(3.,dtype=self.dtype)
         y = zeros(shape(x),x.dtype)
@@ -206,21 +206,21 @@
     #    assert_array_equal(x,y)
 
 try:
-    class test_scopy(base_copy):
+    class TestScopy(BaseCopy):
         blas_func = fblas.scopy
         dtype = float32
 except AttributeError:
-    class test_scopy: pass
-class test_dcopy(base_copy):
+    class TestScopy: pass
+class TestDcopy(BaseCopy):
     blas_func = fblas.dcopy
     dtype = float64
 try:
-    class test_ccopy(base_copy):
+    class TestCcopy(BaseCopy):
         blas_func = fblas.ccopy
         dtype = complex64
 except AttributeError:
-    class test_ccopy: pass
-class test_zcopy(base_copy):
+    class TestCcopy: pass
+class TestZcopy(BaseCopy):
     blas_func = fblas.zcopy
     dtype = complex128
 
@@ -228,7 +228,7 @@
 ##################################################
 ### Test blas ?swap
 
-class base_swap(NumpyTestCase):
+class BaseSwap(NumpyTestCase):
     def check_simple(self):
         x = arange(3.,dtype=self.dtype)
         y = zeros(shape(x),x.dtype)
@@ -282,21 +282,21 @@
         assert(0)
 
 try:
-    class test_sswap(base_swap):
+    class TestSswap(BaseSwap):
         blas_func = fblas.sswap
         dtype = float32
 except AttributeError:
-    class test_sswap: pass
-class test_dswap(base_swap):
+    class TestSswap: pass
+class TestDswap(BaseSwap):
     blas_func = fblas.dswap
     dtype = float64
 try:
-    class test_cswap(base_swap):
+    class TestCswap(BaseSwap):
         blas_func = fblas.cswap
         dtype = complex64
 except AttributeError:
-    class test_cswap: pass
-class test_zswap(base_swap):
+    class TestCswap: pass
+class TestZswap(BaseSwap):
     blas_func = fblas.zswap
     dtype = complex128
 
@@ -304,7 +304,7 @@
 ### Test blas ?gemv
 ### This will be a mess to test all cases.
 
-class base_gemv(NumpyTestCase):
+class BaseGemv(NumpyTestCase):
     def get_data(self,x_stride=1,y_stride=1):
         mult = array(1, dtype = self.dtype)
         if self.dtype in [complex64, complex128]:
@@ -386,21 +386,21 @@
             pass
 
 try:
-    class test_sgemv(base_gemv):
+    class TestSgemv(BaseGemv):
         blas_func = fblas.sgemv
         dtype = float32
 except AttributeError:
-    class test_sgemv: pass
-class test_dgemv(base_gemv):
+    class TestSgemv: pass
+class TestDgemv(BaseGemv):
     blas_func = fblas.dgemv
     dtype = float64
 try:
-    class test_cgemv(base_gemv):
+    class TestCgemv(BaseGemv):
         blas_func = fblas.cgemv
         dtype = complex64
 except AttributeError:
-    class test_cgemv: pass
-class test_zgemv(base_gemv):
+    class TestCgemv: pass
+class TestZgemv(BaseGemv):
     blas_func = fblas.zgemv
     dtype = complex128
 
@@ -409,7 +409,7 @@
 ### Test blas ?ger
 ### This will be a mess to test all cases.
 
-class base_ger(NumpyTestCase):
+class BaseGer(NumpyTestCase):
     def get_data(self,x_stride=1,y_stride=1):
         from numpy.random import normal
         alpha = array(1., dtype = self.dtype)
@@ -449,10 +449,10 @@
         except:
             pass
 
-class test_sger(base_ger):
+class TestSger(BaseGer):
     blas_func = fblas.sger
     dtype = float32
-class test_dger(base_ger):
+class TestDger(BaseGer):
     blas_func = fblas.dger
     dtype = float64
 """
@@ -461,7 +461,7 @@
 ### This will be a mess to test all cases.
 
 """
-class base_ger_complex(base_ger):
+class BaseGerComplex(BaseGer):
     def get_data(self,x_stride=1,y_stride=1):
         from numpy.random import normal
         alpha = array(1+1j, dtype = self.dtype)
@@ -493,24 +493,24 @@
     #    self.blas_func(x,y,a,incy=2)
     #    assert_array_almost_equal(desired_a,a)
 
-class test_cgeru(base_ger_complex):
+class TestCgeru(BaseGerComplex):
     blas_func = fblas.cgeru
     dtype = complex64
     def transform(self,x):
         return x
-class test_zgeru(base_ger_complex):
+class TestZgeru(BaseGerComplex):
     blas_func = fblas.zgeru
     dtype = complex128
     def transform(self,x):
         return x
 
-class test_cgerc(base_ger_complex):
+class TestCgerc(BaseGerComplex):
     blas_func = fblas.cgerc
     dtype = complex64
     def transform(self,x):
         return conjugate(x)
 
-class test_zgerc(base_ger_complex):
+class TestZgerc(BaseGerComplex):
     blas_func = fblas.zgerc
     dtype = complex128
     def transform(self,x):

Modified: trunk/scipy/misc/tests/test_pilutil.py
===================================================================
--- trunk/scipy/misc/tests/test_pilutil.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/misc/tests/test_pilutil.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -10,7 +10,7 @@
 
 datapath = os.path.dirname(__file__)
 
-class test_pilutil(ParametricTestCase):
+class TestPILUtil(ParametricTestCase):
     def test_imresize(self):
         im = N.random.random((10,20))
         for T in N.sctypes['float'] + [float]:

Modified: trunk/scipy/optimize/tests/test_zeros.py
===================================================================
--- trunk/scipy/optimize/tests/test_zeros.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/optimize/tests/test_zeros.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -51,7 +51,7 @@
 functions = [f2,f3,f4,f5,f6]
 fstrings = ['f2','f3','f4','f5','f6']
 
-class test_basic(NumpyTestCase) :
+class TestBasic(NumpyTestCase) :
     def run_test(self, method, name):
         a = .5
         b = sqrt(3)

Modified: trunk/scipy/sparse/tests/test_sparse.py
===================================================================
--- trunk/scipy/weave/tests/test_build_tools.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/weave/tests/test_build_tools.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -38,7 +38,7 @@
         assert(d == d2)
         assert(is_writable(d))
 
-class test_configure_temp_dir(test_configure_build_dir):
+class TestConfigureTempDir(TestConfigureBuildDir):
     def check_default(self):
         " default behavior returns tempdir"
         # this'll fail if the temp directory isn't writable.

Modified: trunk/scipy/weave/tests/test_c_spec.py
===================================================================
--- trunk/scipy/weave/tests/test_c_spec.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/weave/tests/test_c_spec.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -570,84 +570,84 @@
         c = test(b)
         assert( c['hello'] == 5)
 
-class test_msvc_int_converter(test_int_converter):
+class TestMsvcIntConverter(TestIntConverter):
     compiler = 'msvc'
-class test_unix_int_converter(test_int_converter):
+class TestUnixIntConverter(TestIntConverter):
     compiler = ''
-class test_gcc_int_converter(test_int_converter):
+class TestGccIntConverter(TestIntConverter):
     compiler = 'gcc'
 
-class test_msvc_float_converter(test_float_converter):
+class TestMsvcFloatConverter(TestFloatConverter):
     compiler = 'msvc'
 
-class test_msvc_float_converter(test_float_converter):
+class TestMsvcFloatConverter(TestFloatConverter):
     compiler = 'msvc'
-class test_unix_float_converter(test_float_converter):
+class TestUnixFloatConverter(TestFloatConverter):
     compiler = ''
-class test_gcc_float_converter(test_float_converter):
+class TestGccFloatConverter(TestFloatConverter):
     compiler = 'gcc'
 
-class test_msvc_complex_converter(test_complex_converter):
+class TestMsvcComplexConverter(TestComplexConverter):
     compiler = 'msvc'
-class test_unix_complex_converter(test_complex_converter):
+class TestUnixComplexConverter(TestComplexConverter):
     compiler = ''
-class test_gcc_complex_converter(test_complex_converter):
+class TestGccComplexConverter(TestComplexConverter):
     compiler = 'gcc'
 
-class test_msvc_file_converter(test_file_converter):
+class TestMsvcFileConverter(TestFileConverter):
     compiler = 'msvc'
-class test_unix_file_converter(test_file_converter):
+class TestUnixFileConverter(TestFileConverter):
     compiler = ''
-class test_gcc_file_converter(test_file_converter):
+class TestGccFileConverter(TestFileConverter):
     compiler = 'gcc'
 
-class test_msvc_callable_converter(test_callable_converter):
+class TestMsvcCallableConverter(TestCallableConverter):
     compiler = 'msvc'
-class test_unix_callable_converter(test_callable_converter):
+class TestUnixCallableConverter(TestCallableConverter):
     compiler = ''
-class test_gcc_callable_converter(test_callable_converter):
+class TestGccCallableConverter(TestCallableConverter):
     compiler = 'gcc'
 
-class test_msvc_sequence_converter(test_sequence_converter):
+class TestMsvcSequenceConverter(TestSequenceConverter):
     compiler = 'msvc'
-class test_unix_sequence_converter(test_sequence_converter):
+class TestUnixSequenceConverter(TestSequenceConverter):
     compiler = ''
-class test_gcc_sequence_converter(test_sequence_converter):
+class TestGccSequenceConverter(TestSequenceConverter):
     compiler = 'gcc'
 
-class test_msvc_string_converter(test_string_converter):
+class TestMsvcStringConverter(TestStringConverter):
     compiler = 'msvc'
-class test_unix_string_converter(test_string_converter):
+class TestUnixStringConverter(TestStringConverter):
     compiler = ''
-class test_gcc_string_converter(test_string_converter):
+class TestGccStringConverter(TestStringConverter):
     compiler = 'gcc'
 
-class test_msvc_list_converter(test_list_converter):
+class TestMsvcListConverter(TestListConverter):
     compiler = 'msvc'
-class test_unix_list_converter(test_list_converter):
+class TestUnixListConverter(TestListConverter):
     compiler = ''
-class test_gcc_list_converter(test_list_converter):
+class TestGccListConverter(TestListConverter):
     compiler = 'gcc'
 
-class test_msvc_tuple_converter(test_tuple_converter):
+class TestMsvcTupleConverter(TestTupleConverter):
     compiler = 'msvc'
-class test_unix_tuple_converter(test_tuple_converter):
+class TestUnixTupleConverter(TestTupleConverter):
     compiler = ''
-class test_gcc_tuple_converter(test_tuple_converter):
+class TestGccTupleConverter(TestTupleConverter):
     compiler = 'gcc'
 
-class test_msvc_dict_converter(test_dict_converter):
+class TestMsvcDictConverter(TestDictConverter):
     compiler = 'msvc'
-class test_unix_dict_converter(test_dict_converter):
+class TestUnixDictConverter(TestDictConverter):
     compiler = ''
-class test_gcc_dict_converter(test_dict_converter):
+class TestGccDictConverter(TestDictConverter):
     compiler = 'gcc'
 
-class test_msvc_instance_converter(test_instance_converter):
+class TestMsvcInstanceConverter(TestInstanceConverter):
     compiler = 'msvc'
-class test_unix_instance_converter(test_instance_converter):
+class TestUnixInstanceConverter(TestInstanceConverter):
     compiler = ''
-class test_gcc_instance_converter(test_instance_converter):
+class TestGccInstanceConverter(TestInstanceConverter):
     compiler = 'gcc'
 
 def setup_test_location():

Modified: trunk/scipy/weave/tests/test_numpy_scalar_spec.py
===================================================================
--- trunk/scipy/weave/tests/test_numpy_scalar_spec.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/weave/tests/test_numpy_scalar_spec.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -112,14 +112,14 @@
         result = inline_tools.inline("return_val=1.0/a;",['a'])
         assert( result==.5-.5j)
 
-class test_msvc_numpy_complex_scalar_converter(
-                  test_numpy_complex_scalar_converter):
+class TestMsvcNumpyComplexScalarConverter(
+                  TestNumpyComplexScalarConverter):
     compiler = 'msvc'
-class test_unix_numpy_complex_scalar_converter(
-                  test_numpy_complex_scalar_converter):
+class TestUnixNumpyComplexScalarConverter(
+                  TestNumpyComplexScalarConverter):
     compiler = ''
-class test_gcc_numpy_complex_scalar_converter(
-                  test_numpy_complex_scalar_converter):
+class TestGccNumpyComplexScalarConverter(
+                  TestNumpyComplexScalarConverter):
     compiler = 'gcc'
 
 

Modified: trunk/scipy/weave/tests/test_scxx_sequence.py
===================================================================
--- trunk/scipy/weave/tests/test_scxx_sequence.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/weave/tests/test_scxx_sequence.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -20,7 +20,7 @@
 
 from UserList import UserList
 
-class _test_sequence_base(NumpyTestCase):
+class _TestSequenceBase(NumpyTestCase):
     seq_type = None
 
     def check_conversion(self,level=5):
@@ -179,7 +179,7 @@
         print 'weave:', t2 - t1
         assert list(b) == list(a)
 
-class test_tuple(_test_sequence_base):
+class TestTuple(_TestSequenceBase):
     seq_type = tuple
 
     def check_set_item_operator_equal_fail(self,level=5):
@@ -225,7 +225,7 @@
         except IndexError:
             pass
 
-class test_list(_test_sequence_base):
+class TestList(_TestSequenceBase):
     seq_type = list
     def check_append_passed_item(self,level=5):
         a = []

Modified: trunk/scipy/weave/tests/test_size_check.py
===================================================================
--- trunk/scipy/weave/tests/test_size_check.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/weave/tests/test_size_check.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -98,7 +98,7 @@
         x,y = (5,5),(4,5)
         self.generic_error_test(x,y)
 
-class test_dummy_array(test_binary_op_size):
+class TestDummyArray(TestBinaryOpSize):
     def generic_test(self,x,y,desired):
         if type(x) is type(()):
             x = ones(x)




More information about the Scipy-svn mailing list
--- trunk/scipy/sparse/tests/test_sparse.py	2007-11-13 04:04:54 UTC (rev 3514)
+++ trunk/scipy/sparse/tests/test_sparse.py	2007-11-13 04:18:23 UTC (rev 3515)
@@ -26,7 +26,7 @@
 from scipy.linsolve import splu
 restore_path()
 
-class _test_cs:
+class _TestCs:
     def setUp(self):
         self.dat = matrix([[1,0,0,2],[3,0,1,0],[0,2,0,0]],'d')
         self.datsp = self.spmatrix(self.dat)
@@ -388,7 +388,7 @@
             assert_array_equal(numpy.diag(A),extract_diagonal(self.spmatrix(A)))
 
 
-class _test_horiz_slicing:
+class _TestHorizSlicing:
     """Tests horizontal slicing (e.g. [:, 0]).  Tests for individual sparse
     matrix types that implement this should derive from this class.
     """
@@ -422,7 +422,7 @@
         assert caught == 2
 
 
-class _test_vert_slicing:
+class _TestVertSlicing:
     """Tests vertical slicing (e.g. [:, 0]).  Tests for individual sparse
     matrix types that implement this should derive from this class.
     """
@@ -648,7 +648,7 @@
 
 
 
-class test_csr(_test_cs, _test_horiz_slicing, _test_vert_slicing,
+class TestCsr(_TestCs, _TestHorizSlicing, _TestVertSlicing,
                _test_slicing, _test_arith, NumpyTestCase):
     spmatrix = csr_matrix
 
@@ -714,7 +714,7 @@
     def check_empty(self):
         """Test manipulating empty matrices. Fails in SciPy SVN <= r1768
         """
         # This test should be made global (in _test_cs), but first we
         # need a uniform argument order / syntax for constructing an
         # empty sparse matrix. (coo_matrix is currently different).
         shape = (5, 5)
@@ -757,7 +757,7 @@
         assert b.shape == (2,2)
         assert_equal( ab, aa[i0,i1[0]:i1[1]] )
 
-class test_csc(_test_cs, _test_horiz_slicing, _test_vert_slicing,
+class TestCsc(_TestCs, _TestHorizSlicing, _TestVertSlicing,
                _test_slicing, _test_arith, NumpyTestCase):
     spmatrix = csc_matrix
 
@@ -799,7 +799,7 @@
     def check_empty(self):
         """Test manipulating empty matrices. Fails in SciPy SVN <= r1768
         """
         # This test should be made global (in _test_cs), but first we
         # need a uniform argument order / syntax for constructing an
         # empty sparse matrix. (coo_matrix is currently different).
         shape = (5, 5)
@@ -841,7 +841,7 @@
         assert_equal(b.shape, (2,2))
         assert_equal( ab, aa[i0,i1[0]:i1[1]] )
 
-class test_dok(_test_cs, NumpyTestCase):
+class TestDok(_TestCs, NumpyTestCase):
     spmatrix = dok_matrix
 
     def check_mult(self):
@@ -948,7 +948,7 @@
         assert_equal(caught,5)
 
 
-class test_lil(_test_cs, _test_horiz_slicing, NumpyTestCase,
+class TestLil(_TestCs, _TestHorizSlicing, NumpyTestCase,
                ParametricTestCase):
     spmatrix = lil_matrix
 
@@ -714,7 +714,7 @@
         """Test manipulating empty matrices. Fails in SciPy SVN <= r1768
         """
-        # This test should be made global (in _test_cs), but first we
+        # This test should be made global (in _TestCs), but first we
         # need a uniform argument order / syntax for constructing an
         # empty sparse matrix. (coo_matrix is currently different).
@@ -799,7 +799,7 @@
         """Test manipulating empty matrices. Fails in SciPy SVN <= r1768
         """
-        # This test should be made global (in _test_cs), but first we
+        # This test should be made global (in _TestCs), but first we
         # need a uniform argument order / syntax for constructing an
         # empty sparse matrix. (coo_matrix is currently different).

Modified: trunk/scipy/weave/tests/test_build_tools.py
===================================================================